diff --git a/Gemfile b/Gemfile
index 8693b63053a762dc6d45a789f88a28fd82f11289..233a50c6e4756f462d3e697bc5c4482ed3033641 100644
--- a/Gemfile
+++ b/Gemfile
@@ -344,7 +344,7 @@ group :development, :test do
   gem 'benchmark-ips', '~> 2.3.0', require: false
 
   gem 'license_finder', '~> 2.1.0', require: false
-  gem 'knapsack', '~> 1.14.0'
+  gem 'knapsack', '~> 1.11.0'
 
   gem 'activerecord_sane_schema_dumper', '0.2'
 
diff --git a/Gemfile.lock b/Gemfile.lock
index 2990bf72ad950246a187427e3a96dceb53dc71d7..deaf3ded2f990baefd2df27fe270166e4f402aaf 100644
--- a/Gemfile.lock
+++ b/Gemfile.lock
@@ -422,8 +422,9 @@ GEM
       actionpack (>= 3.0.0)
       activesupport (>= 3.0.0)
     kgio (2.10.0)
-    knapsack (1.14.0)
+    knapsack (1.11.0)
       rake
+      timecop (>= 0.1.0)
     kubeclient (2.2.0)
       http (= 0.9.8)
       recursive-open-struct (= 1.0.0)
@@ -1001,7 +1002,7 @@ DEPENDENCIES
   json-schema (~> 2.6.2)
   jwt (~> 1.5.6)
   kaminari (~> 0.17.0)
-  knapsack (~> 1.14.0)
+  knapsack (~> 1.11.0)
   kubeclient (~> 2.2.0)
   letter_opener_web (~> 1.3.0)
   license_finder (~> 2.1.0)
diff --git a/scripts/prepare_build.sh b/scripts/prepare_build.sh
index 6d6a867764a85689e950c983193888e004311c8b..68114d149c4c1303353cef600ced01eb80c0b57a 100644
--- a/scripts/prepare_build.sh
+++ b/scripts/prepare_build.sh
@@ -8,10 +8,9 @@ if [ "$USE_BUNDLE_INSTALL" != "false" ]; then
     bundle install --clean $BUNDLE_INSTALL_FLAGS && bundle check
 fi
 
 # Only install fog-aws/mime-types after bundle install! Otherwise oddly some native
 # gems could not be found under some circumstance. No idea why, hours wasted.
-# TODO: remove workaround on !10156
-retry gem install fog-aws mime-types
+retry gem install knapsack fog-aws mime-types
 
 cp config/gitlab.yml.example config/gitlab.yml
@@ -8,10 +8,9 @@ if [ "$USE_BUNDLE_INSTALL" != "false" ]; then
 fi
 
-# Only install fog-aws/mime-types after bundle install! Otherwise oddly some native
+# Only install knapsack after bundle install! Otherwise oddly some native
 # gems could not be found under some circumstance. No idea why, hours wasted.